@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function
-from . import convert
-from . import model
+from .convert import Convert
+from .process import Process
+from . import model     # Delete in later patch
 
 from ._version import get_versions
 __version__ = get_versions()['version']
