@@ -4,8 +4,10 @@ Include code to unpack manufacturer-specific data files into an interoperable ne
 The current version supports:
 
 - Simrad EK60 echosounder ``.raw`` data
+- Simrad EK80 echosounder ``.raw`` data
 - ASL Environmental Sciences AZFP echosounder ``.01A`` data
 """
 from .convert import Convert
 from .ek60 import ConvertEK60
+from .ek80 import ConvertEK80
 from .azfp import ConvertAZFP
\ No newline at end of file
