@@ -49,7 +49,9 @@ class SetGroupsEK60(SetGroupsBase):
             if self.format == '.nc':
                 ds.to_netcdf(path=self.file_path, mode='a', group='Environment')
             elif self.format == '.zarr':
-                ds.to_zarr(store=self.file_path, mode='a', group='Environment')
+                # Only save environment group if not appending to an existing .zarr file
+                if not self.append_zarr:
+                    ds.to_zarr(store=self.file_path, mode='a', group='Environment')
 
     def set_platform(self, platform_dict):
         """Set the Platform group in the EK60 nc file.
@@ -86,16 +88,6 @@ class SetGroupsEK60(SetGroupsBase):
                             'standard_name': 'platform_heave_angle',
                             'units': 'arc_degree',
                             'valid_range': (-90.0, 90.0)}),
-                 'latitude': (['location_time'], platform_dict['lat'],
-                              {'long_name': 'Platform latitude',
-                               'standard_name': 'latitude',
-                               'units': 'degrees_north',
-                               'valid_range': (-90.0, 90.0)}),
-                 'longitude': (['location_time'], platform_dict['lon'],
-                               {'long_name': 'Platform longitude',
-                                'standard_name': 'longitude',
-                                'units': 'degrees_east',
-                                'valid_range': (-180.0, 180.0)}),
                  'water_level': ([], platform_dict['water_level'],
                                  {'long_name': 'z-axis distance from the platform coordinate system '
                                                'origin to the sonar transducer',
@@ -106,17 +98,30 @@ class SetGroupsEK60(SetGroupsBase):
                                        'calendar': 'gregorian',
                                        'long_name': 'Timestamps for position datagrams',
                                        'standard_name': 'time',
-                                       'units': 'seconds since 1900-01-01'}),
-                        'location_time': (['location_time'], location_time,
-                                          {'axis': 'T',
-                                           'calendar': 'gregorian',
-                                           'long_name': 'Timestamps for NMEA position datagrams',
-                                           'standard_name': 'time',
-                                           'units': 'seconds since 1900-01-01'})
+                                       'units': 'seconds since 1900-01-01'})
                         },
                 attrs={'platform_code_ICES': platform_dict['platform_code_ICES'],
                        'platform_name': platform_dict['platform_name'],
                        'platform_type': platform_dict['platform_type']})
+            if len(location_time) > 0:
+                ds_loc = xr.Dataset(
+                    {'latitude': (['location_time'], platform_dict['lat'],
+                                  {'long_name': 'Platform latitude',
+                                   'standard_name': 'latitude',
+                                   'units': 'degrees_north',
+                                   'valid_range': (-90.0, 90.0)}),
+                     'longitude': (['location_time'], platform_dict['lon'],
+                                   {'long_name': 'Platform longitude',
+                                    'standard_name': 'longitude',
+                                    'units': 'degrees_east',
+                                    'valid_range': (-180.0, 180.0)})},
+                    coords={'location_time': (['location_time'], location_time,
+                                              {'axis': 'T',
+                                               'calendar': 'gregorian',
+                                               'long_name': 'Timestamps for NMEA position datagrams',
+                                               'standard_name': 'time',
+                                               'units': 'seconds since 1900-01-01'})})
+                ds = xr.merge([ds, ds_loc])
 
             if 'ping_slice' in platform_dict:
                 lower = (platform_dict['ping_slice'][0] - np.datetime64('1900-01-01T00:00:00')) \
@@ -125,11 +130,23 @@ class SetGroupsEK60(SetGroupsBase):
                             / np.timedelta64(1, 's')
                 ds = ds.sel(ping_time=slice(lower, upper)).sel(location_time=slice(lower, upper))
 
+            # Configure compression settings
+            nc_encoding = {}
+            zarr_encoding = {}
+            if self.compress:
+                nc_settings = dict(zlib=True, complevel=4)
+                nc_encoding = {var: nc_settings for var in ds.data_vars}
+                zarr_settings = dict(compressor=zarr.Blosc(cname='zstd', clevel=3, shuffle=2))
+                zarr_encoding = {var: zarr_settings for var in ds.data_vars}
+
             # save to file
             if self.format == '.nc':
-                ds.to_netcdf(path=platform_dict['path'], mode='a', group='Platform')
+                ds.to_netcdf(path=platform_dict['path'], mode='a', group='Platform', encoding=nc_encoding)
             elif self.format == '.zarr':
-                ds.to_zarr(store=platform_dict['path'], mode='a', group='Platform')
+                if not self.append_zarr or platform_dict['overwrite_plat']:
+                    ds.to_zarr(store=platform_dict['path'], mode='w', group='Platform', encoding=zarr_encoding)
+                else:
+                    ds.to_zarr(store=platform_dict['path'], mode='a', group='Platform', append_dim='ping_time')
 
     def set_beam(self, beam_dict):
         """Set the Beam group in the EK60 nc file.
@@ -152,8 +169,8 @@ class SetGroupsEK60(SetGroupsBase):
                 {'backscatter_r': (['frequency', 'ping_time', 'range_bin'], beam_dict['backscatter_r'],
                                    {'long_name': 'Backscatter power',
                                     'units': 'dB'}),
-                 'angle_athwardship': (['frequency', 'ping_time', 'range_bin'], beam_dict['angle_dict'][:, :, :, 0],
-                                       {'long_name': 'electrical athwardship angle'}),
+                 'angle_athwartship': (['frequency', 'ping_time', 'range_bin'], beam_dict['angle_dict'][:, :, :, 0],
+                                       {'long_name': 'electrical athwartship angle'}),
                  'angle_alongship': (['frequency', 'ping_time', 'range_bin'], beam_dict['angle_dict'][:, :, :, 1],
                                        {'long_name': 'electrical alongship angle'}),
                  'beam_type': ('frequency', beam_dict['beam_type'],
@@ -267,14 +284,20 @@ class SetGroupsEK60(SetGroupsBase):
             ds['gpt_software_version'] = ('frequency', beam_dict['gpt_software_version'])
             ds['sa_correction'] = ('frequency', beam_dict['sa_correction'])
 
-            n_settings = {}
-            z_settings = {}
+            # Configure compression settings
+            nc_encoding = {}
+            zarr_encoding = {}
             if self.compress:
-                n_settings = {'backscatter_r': {'zlib': True, 'complevel': 4}}
-                z_settings = {'backscatter_r': {'compressor': zarr.Blosc(cname='zstd', clevel=3, shuffle=2)}}
+                nc_settings = dict(zlib=True, complevel=4)
+                nc_encoding = {var: nc_settings for var in ds.data_vars}
+                zarr_settings = dict(compressor=zarr.Blosc(cname='zstd', clevel=3, shuffle=2))
+                zarr_encoding = {var: zarr_settings for var in ds.data_vars}
 
             # save to file
             if self.format == '.nc':
-                ds.to_netcdf(path=beam_dict['path'], mode='a', group='Beam', encoding=n_settings)
+                ds.to_netcdf(path=beam_dict['path'], mode='a', group='Beam', encoding=nc_encoding)
             elif self.format == '.zarr':
-                ds.to_zarr(store=beam_dict['path'], mode='a', group='Beam', encoding=z_settings)
+                if not self.append_zarr or beam_dict['overwrite_beam']:
+                    ds.to_zarr(store=beam_dict['path'], mode='w', group='Beam', encoding=zarr_encoding)
+                else:
+                    ds.to_zarr(store=beam_dict['path'], mode='a', group='Beam', append_dim='ping_time')
